@@ -3,7 +3,7 @@ Python bindings to odesk API
 python-odesk version 0.1
 (C) 2010 oDesk
 """
-VERSION = (0, 1, 1, 'final', 1)
+VERSION = (0, 1, 2, 'final', 1)
 
 from datetime import date
 
@@ -260,11 +260,8 @@ class Auth(Namespace):
 
     def check_token(self):
         url = 'keys/token'
-        try:
-            result = self.get(url)
-            return True
-        except HTTP403ForbiddenError:
-            return False
+        result = self.get(url)
+        return result['token'], result['auth_user']
 
     def revoke_token(self):
         url = 'keys/token'
@@ -299,7 +296,7 @@ class Team(Namespace):
         if date:
             url += '/%s' % str(date)
         result = self.get(url)
-        snapshots = result['snapshots']['snapshot']
+        snapshots = result.get('snapshots', {}).get('snapshot', [])
         if not isinstance(snapshots, list):
             snapshots = [snapshots]
         #not sure we need to return user
